<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script src="https://kit.fontawesome.com/a076d05399.js"></script> <!-- Font Awesome for Icons -->
</head>
<body class="bg-gray-100">
<?php //include "header.php";?>
    <div class="flex h-screen">
        <!-- Sidebar -->
        <?php include "side_bar.php";?>
        <!-- Main Content -->
        <main class="flex-1 p-6 ml-64">
            <!-- Top Navigation -->
          <?php include "header.php";?>

            <!-- Dashboard Cards -->
            <div class="grid grid-cols-3 gap-4 mt-6">
                <?php 
                    $stats = [
                        'Total Clients' => 26,
                        'Total IB' => 25,
                        'Pending Clients' => 1,
                        'Pending Deposit' => 6,
                        'Pending Withdraw' => 3,
                        'Pending IB Withdraw' => 2,
                        'Active Traders' => 6,
                        'FTD Users' => 6,
                        'Non FTD Users' => 45,
                        'Pending IB Request' => 2,
                        'Pending Bank Details Request' => 1
                    ];
                    foreach ($stats as $title => $value) {
                        echo "<div class='bg-white shadow p-6 rounded-lg'>
                                <h2 class='text-xl font-semibold'>$title</h2>
                                <p class='text-2xl font-bold text-orange-600'>$value</p>
                              </div>";
                    }
                ?>
            </div>

            <!-- Tab Navigation -->
            <div class="mb-6"><br><br>
                <ul class="flex border-b-2 border-gray-300">
                    <li class="mr-4">
                        <button id="tab-1" class="py-2 px-4 text-lg text-gray-700 font-semibold focus:outline-none" onclick="showTab(1)">Deposits & Withdrawals</button>
                    </li>
                    <li>
                        <button id="tab-2" class="py-2 px-4 text-lg text-gray-700 font-semibold focus:outline-none" onclick="showTab(2)">Client Registrations</button>
                    </li>
                </ul>
            </div>

            <!-- Graphical Representation -->
            <div id="chart-1" class="bg-white shadow p-6 rounded-lg">
                <h2 class="text-xl font-semibold mb-4">Deposits vs Withdrawals vs IB Withdrawals</h2>
                <canvas id="depositWithdrawalChart"></canvas>
            </div>

            <div id="chart-2" class="bg-white shadow p-6 rounded-lg hidden">
                <h2 class="text-xl font-semibold mb-4">Client Registrations Over Time</h2>
                <canvas id="clientRegistrationChart"></canvas>
            </div>

            <!-- Stats Section -->
            <div class="grid grid-cols-4 gap-4 mt-6">
                <?php 
                    $stats = [
                        'Daily Deposits' => 26,
                        'Weekly Deposits ' => 25,
                        'Monthly Deposits' => 1,
                        'Total Deposits' => 2,
                        'Daily Withdrawal' => 6,
                        'Weekly Withdrawal' => 3,
                        'Monthly Withdrawal' => 2,
                        'Total Withdrawal' => 1,
                        'Daily IB Withdrawal' => 6,
                        'Weekly IB Withdrawal' => 6,
                        'Monthly IB Withdrawal' => 45,
                        'Total IB Withdrawal' => 1234
                    ];
                    foreach ($stats as $title => $value) {
                        echo "<div class='bg-white shadow p-6 rounded-lg'>
                                <h2 class='text-xl font-semibold'>$title</h2>
                                <p class='text-2xl font-bold text-orange-600'>$value</p>
                              </div>";
                    }
                ?>
            </div>
<?php include "footer.php";?>
        </main>
    </div>

    <script>
        // Function to switch between tabs
        function showTab(tabNumber) {
            // Hide all charts
            document.getElementById('chart-1').classList.add('hidden');
            document.getElementById('chart-2').classList.add('hidden');

            // Reset button styles
            document.getElementById('tab-1').classList.remove('text-orange-600', 'font-semibold');
            document.getElementById('tab-2').classList.remove('text-orange-600', 'font-semibold');

            // Show selected chart
            if (tabNumber === 1) {
                document.getElementById('chart-1').classList.remove('hidden');
                document.getElementById('tab-1').classList.add('text-orange-600', 'font-semibold');
            } else if (tabNumber === 2) {
                document.getElementById('chart-2').classList.remove('hidden');
                document.getElementById('tab-2').classList.add('text-orange-600', 'font-semibold');
            }
        }

        // Data for Deposits, Withdrawals, and IB Withdrawals (stacked bar chart)
        var ctx1 = document.getElementById('depositWithdrawalChart').getContext('2d');
        var depositWithdrawalChart = new Chart(ctx1, {
            type: 'bar',
            data: {
                labels: ['Deposits', 'Withdrawals', 'IB Withdrawals'],
                datasets: [{
                    label: 'Deposits',
                    data: [6, 0, 0],
                    backgroundColor: 'rgba(0, 123, 255, 0.6)',
                    borderColor: 'rgba(0, 123, 255, 1)',
                    borderWidth: 1
                }, {
                    label: 'Withdrawals',
                    data: [0, 3, 0],
                    backgroundColor: 'rgba(255, 99, 132, 0.6)',
                    borderColor: 'rgba(255, 99, 132, 1)',
                    borderWidth: 1
                }, {
                    label: 'IB Withdrawals',
                    data: [0, 0, 2],
                    backgroundColor: 'rgba(255, 159, 64, 0.6)',
                    borderColor: 'rgba(255, 159, 64, 1)',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                scales: {
                    x: { stacked: true },
                    y: { stacked: true, beginAtZero: true }
                }
            }
        });

        // Data for Client Registrations (Line chart)
        var ctx2 = document.getElementById('clientRegistrationChart').getContext('2d');
        var clientRegistrationChart = new Chart(ctx2, {
            type: 'line',
            data: {
                labels: ['January', 'February', 'March', 'April', 'May'], // Time periods
                datasets: [{
                    label: 'Clients Registered',
                    data: [5, 10, 8, 12, 15], // Registration numbers
                    borderColor: 'rgba(0, 123, 255, 1)',
                    backgroundColor: 'rgba(0, 123, 255, 0.2)',
                    fill: true,
                    tension: 0.4
                }]
            },
            options: {
                responsive: true,
                plugins: {
                    legend: { position: 'top' },
                    tooltip: {
                        callbacks: {
                            label: function(tooltipItem) {
                                return tooltipItem.dataset.label + ': ' + tooltipItem.raw;
                            }
                        }
                    }
                }
            }
        });

        // Set the initial tab to show (Deposits & Withdrawals)
        showTab(1);
    </script>
</body>
</html>
